@@ -32,6 +32,8 @@ from vtkmodules.vtkInteractionStyle import *
 from vtkmodules.vtkViewsInfovis import *
 from vtkmodules.vtkCommonComputationalGeometry import *
 from vtkmodules.vtkCommonSystem import *
+from vtkmodules.vtkFiltersCellGrid import *
+from vtkmodules.vtkIOCellGrid import *
 from vtkmodules.vtkIOLegacy import *
 from vtkmodules.vtkDomainsChemistry import *
 from vtkmodules.vtkRenderingContextOpenGL2 import *
@@ -39,6 +41,7 @@ from vtkmodules.vtkRenderingVolume import *
 from vtkmodules.vtkImagingMath import *
 from vtkmodules.vtkRenderingVolumeOpenGL2 import *
 from vtkmodules.vtkViewsContext2D import *
+from vtkmodules.vtkImagingColor import *
 from vtkmodules.vtkTestingRendering import *
 from vtkmodules.vtkInteractionImage import *
 from vtkmodules.vtkRenderingRayTracing import *
@@ -51,6 +54,7 @@ from vtkmodules.vtkParallelMPI import *
 from vtkmodules.vtkRenderingLICOpenGL2 import *
 from vtkmodules.vtkRenderingParallelLIC import *
 from vtkmodules.vtkRenderingParallel import *
+from vtkmodules.vtkRenderingVRModels import *
 from vtkmodules.vtkRenderingVR import *
 from vtkmodules.vtkRenderingOpenXR import *
 from vtkmodules.vtkRenderingOpenVR import *
@@ -62,8 +66,8 @@ from vtkmodules.vtkIOVideo import *
 from vtkmodules.vtkIOFFMPEG import *
 from vtkmodules.vtkRenderingFFMPEGOpenGL2 import *
 from vtkmodules.vtkRenderingExternal import *
-from vtkmodules.vtkFiltersCellGrid import *
 from vtkmodules.vtkRenderingCellGrid import *
+from vtkmodules.vtkRenderingAnari import *
 from vtkmodules.vtkParallelMPI4Py import *
 from vtkmodules.vtkIOXdmf2 import *
 from vtkmodules.vtkIOVeraOut import *
@@ -98,28 +102,32 @@ from vtkmodules.vtkIOMPIParallel import *
 from vtkmodules.vtkIOMPIImage import *
 from vtkmodules.vtkIOMINC import *
 from vtkmodules.vtkIOLAS import *
-from vtkmodules.vtkIOInfovis import *
 from vtkmodules.vtkIOImport import *
 from vtkmodules.vtkIOIOSS import *
+from vtkmodules.vtkIOHDF import *
 from vtkmodules.vtkIOH5part import *
 from vtkmodules.vtkIOH5Rage import *
 from vtkmodules.vtkIOGeoJSON import *
 from vtkmodules.vtkIOFides import *
 from vtkmodules.vtkIOFLUENTCFF import *
+from vtkmodules.vtkIOFDS import *
+from vtkmodules.vtkIOInfovis import *
 from vtkmodules.vtkIOExportPDF import *
 from vtkmodules.vtkRenderingGL2PSOpenGL2 import *
 from vtkmodules.vtkIOExportGL2PS import *
+from vtkmodules.vtkIOEngys import *
 from vtkmodules.vtkIOEnSight import *
+from vtkmodules.vtkIOERF import *
 from vtkmodules.vtkIOCityGML import *
 from vtkmodules.vtkIOChemistry import *
 from vtkmodules.vtkIOCesium3DTiles import *
-from vtkmodules.vtkIOCellGrid import *
 from vtkmodules.vtkIOCONVERGECFD import *
-from vtkmodules.vtkIOHDF import *
 from vtkmodules.vtkIOCGNSReader import *
 from vtkmodules.vtkIOAsynchronous import *
+from vtkmodules.vtkIOAlembic import *
 from vtkmodules.vtkIOAMR import *
 from vtkmodules.vtkIOADIOS2 import *
+from vtkmodules.vtkInfovisLayout import *
 from vtkmodules.vtkInfovisBoostGraphAlgorithms import *
 from vtkmodules.vtkImagingStencil import *
 from vtkmodules.vtkImagingStatistics import *
@@ -127,22 +135,16 @@ from vtkmodules.vtkImagingGeneral import *
 from vtkmodules.vtkImagingOpenGL2 import *
 from vtkmodules.vtkImagingMorphological import *
 from vtkmodules.vtkImagingFourier import *
-from vtkmodules.vtkIOGDAL import *
-from vtkmodules.vtkGeovisGDAL import *
-from vtkmodules.vtkCommonColor import *
-from vtkmodules.vtkImagingSources import *
-from vtkmodules.vtkInfovisCore import *
-from vtkmodules.vtkGeovisCore import *
-from vtkmodules.vtkInfovisLayout import *
 from vtkmodules.vtkRenderingAnnotation import *
 from vtkmodules.vtkImagingHybrid import *
-from vtkmodules.vtkImagingColor import *
+from vtkmodules.vtkIOGDAL import *
+from vtkmodules.vtkGeovisGDAL import *
+from vtkmodules.vtkGeovisCore import *
 from vtkmodules.vtkFiltersTopology import *
 from vtkmodules.vtkFiltersTensor import *
 from vtkmodules.vtkFiltersSelection import *
 from vtkmodules.vtkFiltersSMP import *
 from vtkmodules.vtkFiltersReebGraph import *
-from vtkmodules.vtkFiltersReduction import *
 from vtkmodules.vtkFiltersPython import *
 from vtkmodules.vtkFiltersProgrammable import *
 from vtkmodules.vtkFiltersModeling import *
@@ -163,6 +165,7 @@ from vtkmodules.vtkFiltersParallelGeometry import *
 from vtkmodules.vtkFiltersFlowPaths import *
 from vtkmodules.vtkFiltersParallelFlowPaths import *
 from vtkmodules.vtkFiltersParallelDIY2 import *
+from vtkmodules.vtkFiltersTemporal import *
 from vtkmodules.vtkFiltersGeometryPreview import *
 from vtkmodules.vtkFiltersGeneric import *
 from vtkmodules.vtkFiltersAMR import *
@@ -172,9 +175,13 @@ from vtkmodules.vtkDomainsChemistryOpenGL2 import *
 from vtkmodules.vtkCommonPython import *
 from vtkmodules.vtkCommonArchive import *
 from vtkmodules.vtkChartsCore import *
+from vtkmodules.vtkCommonColor import *
+from vtkmodules.vtkImagingSources import *
+from vtkmodules.vtkInfovisCore import *
 from vtkmodules.vtkAcceleratorsVTKmCore import *
 from vtkmodules.vtkAcceleratorsVTKmDataModel import *
 from vtkmodules.vtkAcceleratorsVTKmFilters import *
+from vtkmodules.vtkFiltersReduction import *
 
 
 # useful macro for getting type names
